@@ -25,6 +25,7 @@
 If your goal in creating a Streamlit Component is solely to display HTML code or render a chart from a Python visualization library, 
 Streamlit provides two methods that greatly simplify the process: components.html() and components.iframe().
 """
+from enum import unique
 import time
 import datetime
 import streamlit as st
@@ -36,6 +37,7 @@ from rrshare.rqUtil import (client_pgsql,read_data_from_pg,read_sql_from_pg)
 from rrshare.rqUtil import  (rq_util_date_today,rq_util_get_pre_trade_date,rq_util_get_last_tradedate, trade_date_sse)
 from rrshare.rqUtil import is_before_tradetime_secs_cn, is_trade_time_secs_cn, rq_util_if_trade
 
+
 conn = client_pgsql('rrfactor')
 lastTD = rq_util_get_last_tradedate()
 today_ = rq_util_date_today().strftime('%Y-%m-%d') 
@@ -62,11 +64,13 @@ def out_df_items(df):
 
 
 def swl_rs_valuation():
-    data = pd.read_sql_table('swl_rs_valuation_L3',conn)
+    data = pd.read_sql_table('swl1_rs_L1',conn)
     df = data.copy()
-    df = df.fillna(0)
+    df.rename(columns={'pct_change':'pct_chg'}, inplace=True)
+    df = df.round(2)
     #swl
-    st.text(' 申万行业相对强度和估值')
+    st.text(f'申万行业相对强度和估值')#: {df.trade_date.unique()}')
+    #df.drop(columns=['trade_date'], inplace=True)
     st.dataframe(df, width=1400, height=900)
 
 
@@ -129,14 +133,18 @@ def stock_select_PRS(table_name='stock_select_PRS'):
         print(e)
    
 
-def stock_fundmentals():
-    df = pd.read_sql_table('ROE_CF_SR_INC', conn)
+def stock_fundmentals(): #TODO
+    #df = pd.read_sql_table('ROE_CF_SR_INC', conn)
     code = st.text_input('Input stock code:','300146')
     #code =st.multiselect('selects:',[1,2,3])
     #st.write([code])
-    st.text('股票基本面指标')
-    st.write(df[df.code  == code].T)
-    st.dataframe(df.T, width=1400, height=500)
+    #st.text('股票基本面指标')
+    #st.write(df[df.code  == code].T)
+    #st.dataframe(df.T, width=1400, height=500)
+    st.write("wencai","http://www.iwencai.com/unifiedwap/home/index?qs=pc_~soniu~info~all~homepage~enter")
+
+
+    pass
 
 
 def stock_infomation():
@@ -169,7 +177,8 @@ def other_info():
     st.write('global index ','http://q.10jqka.com.cn/global/')
     st.write('bond','https://cn.investing.com/rates-bonds/u.s.-10-year-bond-yield')
     st.write('myselect','http://quote.eastmoney.com/zixuan/?from=home')
-
+    st.write("金十数据", "https://www.jin10.com/")
+    st.write("商品价格","http://top.100ppi.com/zdb/detail-day---1.html")
          
 def main():
     selects = st.sidebar.selectbox(
@@ -180,8 +189,6 @@ def main():
         swl_rs_valuation()
     if selects == "stock_PRS_top":
         stock_select_PRS()
-    if selects == 'stock_fundamental':
-        stock_fundmentals()
     if selects == 'stock_PRS':
         write_stock_RS_OH_MA()
     if selects == 'stock_infomation':
